AudioTrack mixin

Used to group LocalAudioTrack and RemoteAudioTrack.

Superclass constraints

Properties

disposeFuncCount int
no setterinherited
events → EventsEmitter<TrackEvent>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isActive bool
no setterinherited
isDisposed bool
no setterinherited
kind → TrackType
finalinherited
mediaStream → MediaStream
no setterinherited
mediaStreamTrack → MediaStreamTrack
no setterinherited
mediaType → RTCRtpMediaType
no setterinherited
muted bool
no setterinherited
receiver ↔ RTCRtpReceiver?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender → RTCRtpSender?
no setterinherited
sid String?
getter/setter pairinherited
source → TrackSource
finalinherited
transceiver ↔ RTCRtpTransceiver?
getter/setter pairinherited

Methods

addAudioRenderer({required AudioFrameCallback onFrame, AudioRendererOptions options = const AudioRendererOptions()}) → CancelListenFunc
Register a callback to receive raw PCM audio frames from this track.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
createListener({bool synchronized = false}) → EventsListener<TrackEvent>
inherited
disable() Future<void>
inherited
dispose() Future<bool>
Discards any resources used by the object.
inherited
enable() Future<void>
inherited
getCid() String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
onDispose(OnDisposeFunc func) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
start() Future<bool>
Start this Track if not started. Returns true if started, false if already started
inherited
startCapture() Future<void>
Called by start before this track is marked active.
stop() Future<bool>
Stop this Track if not stopped. Returns true if stopped, false if already stopped
inherited
stopCapture() Future<void>
Called by stop while this track is still active, before the media track is stopped.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited