BaxcloudCreateRoomOptions class

Options for creating a room via POST /v1/rooms

Constructors

BaxcloudCreateRoomOptions({required String roomName, BaxcloudLiveType liveType = BaxcloudLiveType.liveStreaming, int? maxParticipants, int? emptyTimeout, Map<String, dynamic>? metadata})

Properties

emptyTimeout int?
final
hashCode int
The hash code for this object.
no setterinherited
liveType BaxcloudLiveType
final
maxParticipants int?
final
metadata Map<String, dynamic>?
final
roomName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited