BaxcloudRoomInfo class

Room info returned from /v1/rooms API

Constructors

BaxcloudRoomInfo({required String name, required String sid, required int numParticipants, required int maxParticipants, required int createdAt, String? metadata})
BaxcloudRoomInfo.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt int
final
hashCode int
The hash code for this object.
no setterinherited
maxParticipants int
final
metadata String?
final
name String
final
numParticipants int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited