ConnectOptions class

Options used when connecting to the server.

Constructors

ConnectOptions({bool autoSubscribe = true, RTCConfiguration rtcConfiguration = const RTCConfiguration(), ProtocolVersion protocolVersion = ProtocolVersion.v16, ClientProtocolVersion clientProtocolVersion = ClientProtocolVersion.current, Timeouts timeouts = Timeouts.defaultTimeouts})
const

Properties

autoSubscribe bool
Auto-subscribe to existing and new RemoteTrackPublications after successfully connecting to the Room. Defaults to true.
final
clientProtocolVersion → ClientProtocolVersion
The client-to-client protocol version to advertise, used for peer feature negotiation (e.g. RPC v2 data streams). Usually this doesn't need to be modified; pinning to ClientProtocolVersion.v0 forces all peer RPCs to the legacy v1 path.
final
hashCode int
The hash code for this object.
no setterinherited
protocolVersion → ProtocolVersion
The protocol version to be used. Usually this doesn't need to be modified.
final
rtcConfiguration → RTCConfiguration
The default RTCConfiguration to be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeouts → Timeouts
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited