LayoutMode enum

Layout modes for video calls

Inheritance
Available extensions

Values

grid → const LayoutMode

Grid layout - all participants in equal-sized tiles

speaker → const LayoutMode

Speaker view - one large main video, others as thumbnails

focus → const LayoutMode

Focus mode - focus on one participant (larger)

pictureInPicture → const LayoutMode

Picture-in-picture mode - main video with small PIP

Gallery mode - all participants in a grid with equal spacing

activeSpeaker → const LayoutMode

Active speaker mode - automatically focus on the active speaker

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LayoutMode>
A constant List of the values in this enum, in order of their declaration.