ScreenSharingController class

Screen sharing controller and utilities

Constructors

ScreenSharingController()

Properties

hashCode int
The hash code for this object.
no setterinherited
isSharing bool
Whether screen is currently being shared
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenTrack LocalVideoTrack?
Get the screen share track
no setter

Methods

attachRoom(Room room) → void
Attach to a room
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startScreenSharing({bool preserveCamera = true}) Future<void>
Start screen sharing
stopScreenSharing({bool restoreCamera = true}) Future<void>
Stop screen sharing
toggleScreenSharing({bool preserveCamera = true, bool restoreCamera = true}) Future<void>
Toggle screen sharing
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited